pub struct CryptoContext { /* private fields */ }Expand description
Encryption context holding the symmetric key used by generated Sensitive types.
Implementations
Sourceimpl CryptoContext
impl CryptoContext
Sourcepub fn new(key: impl AsRef<[u8]>) -> Result<Self, CryptoError>
pub fn new(key: impl AsRef<[u8]>) -> Result<Self, CryptoError>
Builds a context from raw key bytes.
Sourcepub fn from_provider(provider: &impl KeyProvider) -> Result<Self, CryptoError>
pub fn from_provider(provider: &impl KeyProvider) -> Result<Self, CryptoError>
Builds a context by loading the key from a provider.